==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/DoubleHandler.h <==
// class gnu.java.beans.decoder.DoubleHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class fe17fdd6db78c2e6 gnu_java_beans_decoder_DoubleHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_DoubleHandler_H_
#define _JC_gnu_java_beans_decoder_DoubleHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$sub_refs	_jc_gnu_java_beans_decoder_DoubleHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_DoubleHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$refs	_jc_gnu_java_beans_decoder_DoubleHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$nonrefs	_jc_gnu_java_beans_decoder_DoubleHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$object	_jc_gnu_java_beans_decoder_DoubleHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_DoubleHandler$vmethods	_jc_gnu_java_beans_decoder_DoubleHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_DoubleHandler$vtable	_jc_gnu_java_beans_decoder_DoubleHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_DoubleHandler$vtype	_jc_gnu_java_beans_decoder_DoubleHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_DoubleHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_DoubleHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_DoubleHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_DoubleHandler$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_DoubleHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_DoubleHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_DoubleHandler$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_DoubleHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_DoubleHandler$vmethods	gnu_java_beans_decoder_DoubleHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_DoubleHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_DoubleHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_DoubleHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_DoubleHandler$refs {
    _jc_gnu_java_beans_decoder_DoubleHandler$sub_refs	gnu_java_beans_decoder_DoubleHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_DoubleHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_DoubleHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_DoubleHandler$sub_nonrefs	gnu_java_beans_decoder_DoubleHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_DoubleHandler$object {
	_jc_gnu_java_beans_decoder_DoubleHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_DoubleHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_DoubleHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_DoubleHandler$vtype _jc_gnu_java_beans_decoder_DoubleHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_DoubleHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_DoubleHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_DoubleHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/DoubleHandler.h <==
// class gnu.java.beans.decoder.DoubleHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class fe17fdd6db78c2e6 gnu_java_beans_decoder_DoubleHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_DoubleHandler_H_
#define _JC_gnu_java_beans_decoder_DoubleHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$sub_refs	_jc_gnu_java_beans_decoder_DoubleHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_DoubleHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$refs	_jc_gnu_java_beans_decoder_DoubleHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$nonrefs	_jc_gnu_java_beans_decoder_DoubleHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_DoubleHandler$object	_jc_gnu_java_beans_decoder_DoubleHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_DoubleHandler$vmethods	_jc_gnu_java_beans_decoder_DoubleHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_DoubleHandler$vtable	_jc_gnu_java_beans_decoder_DoubleHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_DoubleHandler$vtype	_jc_gnu_java_beans_decoder_DoubleHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_DoubleHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_DoubleHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_DoubleHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_DoubleHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_DoubleHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_DoubleHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_DoubleHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_DoubleHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_DoubleHandler$vmethods	gnu_java_beans_decoder_DoubleHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_DoubleHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_DoubleHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_DoubleHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_DoubleHandler$refs {
    _jc_gnu_java_beans_decoder_DoubleHandler$sub_refs	gnu_java_beans_decoder_DoubleHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_DoubleHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_DoubleHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_DoubleHandler$sub_nonrefs	gnu_java_beans_decoder_DoubleHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_DoubleHandler$object {
	_jc_gnu_java_beans_decoder_DoubleHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_DoubleHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_DoubleHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_DoubleHandler$vtype _jc_gnu_java_beans_decoder_DoubleHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_DoubleHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_DoubleHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_DoubleHandler_H_ */
